/*
    (C) 1995-97 AROS - The Amiga Research OS
    $Id: setcurrentdirname.c,v 1.1.1.1 2005/03/15 15:54:40 laire Exp $

    Desc: Set the name of the current directory.
    Lang: english
*/
#include <proto/exec.h>
#include <proto/dos.h>
#include <dos/dos.h>
#include <dos/dosextens.h>
#include "dos_intern.h"

/*****************************************************************************

    NAME */
#include <proto/dos.h>

	AROS_LH1(LONG, SetCurrentDirName,

/*  SYNOPSIS */
	AROS_LHA(STRPTR, name, D1),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 93, Dos)

/*  FUNCTION
	Sets the name of the current directory in the CLI structure.
	If the name doesn't fit the old name is kept and a failure
	returned. If the current process doesn't have a CLI structure
	this function does nothing.

    INPUTS
	name - Name for the current directory.

    RESULT
	!=0 on success, 0 on failure.

    NOTES

    EXAMPLE

    BUGS

    SEE ALSO
	GetCurrentDirName()

    INTERNALS

    HISTORY
	27-11-96    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    struct CommandLineInterface *cli = NULL;
    STRPTR s;
    ULONG namelen;

    FAILFORTASKNP(return DOSFALSE;)

    if ((cli = Cli()) == NULL)
	return DOSFALSE;

    s = name;
    while (*s++)
	;
    namelen = s - name - 1;

    if (namelen > (CLI_CURDIRNAME_MAX - 2))
	namelen = CLI_CURDIRNAME_MAX - 2;

    s = AROS_BSTR_ADDR(cli->cli_SetName);

    AROS_BSTR_setstrlen(cli->cli_SetName, namelen);
    CopyMem((APTR)name, s, namelen);
    s[namelen] = '\0';

    return DOSTRUE;

    AROS_LIBFUNC_EXIT
} /* SetCurrentDirName */
